android-23运行时权限管理试行版
=

2018年12月26日

基本用法
-
```java
    /** 
    * 一般用法：适用于通用场景，比如定位，用户拒绝一次就不弹了
    * 1.如果没有请求过权限A，则会请求，根据返回结果回调；
    * 2.如果请求过： 
    *   2.1. 通过->直接回调onGranted
    *   2.2. 拒绝->直接回调onDenied
    */ 
    PermissionManager.newRequest()
                .permissions(Manifest.permission.WRITE_EXTERNAL_STORAGE)
                .onGranted(new PermissionManager.Callback() {
                    @Override
                    public void call() {
                        // SUCCESS
                    }
                })
                .request(activity);


    /** 
    * 强提醒：适用于强权限场景，比如拍照，不管用户拒绝多少次，只要没有点不再询问，始终弹框
    * 1.如果没有请求过权限A，则会弹权限框并根据返回结果回调；
    * 2.如果请求过： 
    *   2.1. 通过                    ->直接回调onGranted
    *   2.2. 拒绝
    *       2.2.1 用户勾选了不在提示   -> onDenied
    *       2.2.2 用户没有勾选        -> 弹权限框并根据返回结果回调；
    */ 
    PermissionManager.newRequest()
            .permissions(Manifest.permission.WRITE_EXTERNAL_STORAGE)
            .constantly()
            .onGranted(new PermissionManager.Callback() {
                @Override
                public void call() {
                    // SUCCESS
                }
            })
            .onDenied(new PermissionManager.Callback() {
                @Override
                public void call() {
                    PermissionManager.goSetting(CommonWebViewActivity.this, "您需要SD卡读写权限才能使用此功能，前往设置打开SD卡读写权限。");
                }
            })
            .request(CommonWebViewActivity.this);
    

    /** 
    * 静默消息：适用于用户无感知请求，如移动账号登录等
    * 1.如果没有请求过权限A     -> onDenied 
    * 2.如果请求过： 
    *   2.1. 通过             ->直接回调onGranted
    *   2.2. 拒绝             -> onDenied
    */ 
    PermissionManager.newRequest()
            .permissions(Manifest.permission.READ_PHONE_STATUS)
            .quietly()
            .onGranted(new PermissionManager.Callback() {
                @Override
                public void call() {
                    // SUCCESS
                }
            })
            .onDenied(new PermissionManager.Callback() {
                @Override
                public void call() {
                    
                }
            })
            .request(CommonWebViewActivity.this);
```


进阶用法
-
```java

    /* 强行提示，即使用户拒绝过，也弹权限框，直到用户勾选不再提示 */
    constantly();
    

    /* 用户无感知，不弹权限请求，有权限则回调onGranted，没有回调onDenied */
    /* 使用场景：移动账号登录，有READ_PHONE_STATUS权限：检测是否移动，并展示登录入口；没有权限：不需要提示用户授予直接不展示入口 */
    quietly();

```